OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Ne povas skribi en la dosierujon „config“!",
    "See %s" : "Vidi %s",
    "Sample configuration detected" : "Ekzempla agordo trovita",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ekzempla agordo estis kopiita en via sistemo. Tio povas paneigi vian instalaĵon, kaj ne estas subtenata. Bv. legi la dokumentaron antaŭ ol fari ŝanĝojn en config.php",
    "The page could not be found on the server." : "La paĝo ne povis esti trovita en la servilo.",
    "Other activities" : "Alia aktivado",
    "%1$s and %2$s" : "%1$s kaj %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s kaj %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s kaj %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s kaj %5$s",
    "Enterprise bundle" : "Aplikaĵa kuniĝo por firmao",
    "Groupware bundle" : "Aplikaĵa kuniĝo por grupa kunlaborado",
    "Hub bundle" : "Koncentrita pakaĵo",
    "Social sharing bundle" : "Aplikaĵa kuniĝo por socia kuhavigo",
    "PHP %s or higher is required." : "PHP %s aŭ pli alta necesas.",
    "PHP with a version lower than %s is required." : "Necesas pli malalta eldono de PHP ol %s.",
    "%sbit or higher PHP required." : "PHP je %sbitoj aŭ pli alta necesas.",
    "The following architectures are supported: %s" : "La sekvaj arkitekturoj estas subtenataj: %s",
    "The following databases are supported: %s" : "La sekvaj datumbazoj estas subtenataj: %s",
    "The command line tool %s could not be found" : "La komandlinia ilo %s ne troviĝis",
    "The library %s is not available." : "La biblioteko %s ne haveblas.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Biblioteko %1$s kun versio pli ol %2$s bezoniĝas. Nuna versio estas %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Biblioteko %1$s kun versio malpli ol %2$s bezoniĝas. Nuna versio estas %3$s.",
    "The following platforms are supported: %s" : "La sekvaj platformoj estas subtenataj: %s",
    "Server version %s or higher is required." : "Servilo kun versio %s aŭ pli bezoniĝas.",
    "Server version %s or lower is required." : "Servilo kun versio %s aŭ malpli bezoniĝas.",
    "Wiping of device %s has started" : "Forviŝado de la aparato %s komencis",
    "Wiping of device »%s« has started" : "Forviŝado de la aparato „%s“ komencis",
    "»%s« started remote wipe" : "„%s“ komencis foran forviŝadon",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "La aparato aŭ aplikaĵo „%s“ komencis la taskon de fora forviŝado. Vi ricevos plian retmesaĝon, kiam la tasko finiĝos",
    "Wiping of device %s has finished" : "La forviŝado de la aparato %s finiĝis",
    "Wiping of device »%s« has finished" : "La forviŝado de la aparato „%s“ finiĝis",
    "»%s« finished remote wipe" : "„%s“ finis la foran forviŝadon",
    "Device or application »%s« has finished the remote wipe process." : "La aparato aŭ aplikaĵo „%s“ finis la taskon de fora forviŝado.",
    "Remote wipe started" : "Defora forviŝado komenciĝis",
    "A remote wipe was started on device %s" : "Defora forviŝado komenciĝis ĉe aparato %s",
    "Remote wipe finished" : "Defora forviŝado finis",
    "The remote wipe on %s has finished" : "La defora forviŝado ĉe %s finis",
    "Authentication" : "Aŭtentigo",
    "Unknown filetype" : "Nekonata dosiertipo",
    "Invalid image" : "Nevalida bildo",
    "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
    "Files" : "Dosieroj",
    "View profile" : "Vidi profilon",
    "today" : "hodiaŭ",
    "tomorrow" : "morgaŭ",
    "yesterday" : "hieraŭ",
    "_in %n day_::_in %n days_" : ["post %n tago","post %n tagoj"],
    "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
    "next month" : "venontmonate",
    "last month" : "lastmonate",
    "_in %n month_::_in %n months_" : ["post %n monato","post %n monatoj"],
    "_%n month ago_::_%n months ago_" : ["antaŭ %n monato","antaŭ %n monatoj"],
    "next year" : "venontjare",
    "last year" : "lastjare",
    "_in %n year_::_in %n years_" : ["post %n jaro","post %n jaroj"],
    "_%n year ago_::_%n years ago_" : ["antaŭ %n jaro","antaŭ %n jaroj"],
    "_in %n hour_::_in %n hours_" : ["post %n horo","post %n horoj"],
    "_%n hour ago_::_%n hours ago_" : ["antaŭ %n horo","antaŭ %n horoj"],
    "_in %n minute_::_in %n minutes_" : ["post %n minuto","post %n minutoj"],
    "_%n minute ago_::_%n minutes ago_" : ["antaŭ %n minuto","antaŭ %n minutoj"],
    "in a few seconds" : "post kelkaj sekundoj",
    "seconds ago" : "antaŭ kelkaj sekundoj",
    "Empty file" : "Malplena dosiero",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulo kun identigilo %s ne ekzistas. Bv. ŝalti ĝin en la aplikaĵa agordo aŭ kontakti vian administranton.",
    "Dot files are not allowed" : "Dosiernomo, kiu komenciĝas per punkto, ne estas permesata",
    "File already exists" : "La dosiero jam ekzistas",
    "Templates" : "Ŝablonoj",
    "Filename contains at least one invalid character" : "Dosiernomo enhavas almenaŭ unu nevalidan signon",
    "Empty filename is not allowed" : "Malplena dosiernomo ne estas permesata",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplikaĵo „%s“ ne instaleblas, ĉar ties dosiero „appinfo“ ne legeblis.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplikaĵo „%s“ ne instaleblas, ĉar ĝi ne kongruas kun tiu servila versio.",
    "__language_name__" : "Esperanto",
    "This is an automatically sent email, please do not reply." : "Tio estas aŭtomate sendita retpoŝtmesaĝo; bv. ne respondi.",
    "Apps" : "Aplikaĵoj",
    "Settings" : "Agordo",
    "Log out" : "Elsaluti",
    "Accounts" : "Kontoj",
    "Email" : "Retpoŝtadreso",
    "Phone" : "Telefono",
    "Twitter" : "Twitter",
    "Website" : "Retejo",
    "Address" : "Adreso",
    "Profile picture" : "Profila bildo",
    "About" : "Pri",
    "Display name" : "Vidiga nomo",
    "Additional settings" : "Plia agordo",
    "You need to enter details of an existing account." : "Vi entajpu detalojn pri ekzistanta konto.",
    "Oracle connection could not be established" : "Konekto al Oracle ne povis stariĝi",
    "For the best results, please consider using a GNU/Linux server instead." : "Por pli bona funkciado, bv. pripensi uzi GNU-Linuksan servilon anstataŭe.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ŝajnas, ke tiu servilo %s uzas 32-bitan PHP-version, kaj ke la agordo „open_basedir“ ekzistas. Tio kaŭzos problemojn pri dosieroj pli grandaj ol 4 GB, kaj do estas tre malrekomendita.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bv. forigi la agordon „open_basedir“ de via php.ini, aŭ uzu 64-bitan version de PHP.",
    "Set an admin password." : "Agordi pasvorton de administranto.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhava interna servo %s devas realigi la interfacon „OCP\\Share_Backend“",
    "Sharing backend %s not found" : "Kunhava interna servo %s ne troviĝas",
    "Sharing backend for %s not found" : "Kunhava interna servo por %s ne troviĝas",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Unknown share type" : "Nekonata kunhava tipo",
    "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
    "Cannot increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
    "Expiration date is in the past" : "Limdato troviĝas en la estinteco",
    "The requested share does not exist anymore" : "La petita kunhavo ne plu ekzistas",
    "Could not find category \"%s\"" : "Ne troviĝis kategorio „%s“",
    "Sunday" : "dimanĉo",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sun." : "dim.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mer.",
    "Thu." : "ĵaŭ.",
    "Fri." : "ven.",
    "Sat." : "sab.",
    "Su" : "Di",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Ĵa",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Januaro",
    "February" : "Februaro",
    "March" : "Marto",
    "April" : "Aprilo",
    "May" : "Majo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Aŭgusto",
    "September" : "Septembro",
    "October" : "Oktobro",
    "November" : "Novembro",
    "December" : "Decembro",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aŭg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Valida pasvorto devas esti provizita",
    "Login canceled by app" : "Ensaluto estis nuligita de aplikaĵo",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "La aplikaĵo „%1$s“ ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas: %2$s",
    "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
    "Application is not enabled" : "La aplikaĵo ne estas ŝaltita",
    "Authentication error" : "Aŭtentiga eraro",
    "Token expired. Please reload page." : "Ĵetono eksvalidiĝis. Bonvolu reŝargi la paĝon.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Neniu datumbaza pelilo (sqlite, mysql, or postgresql) instalita.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Aŭ, se vi preferas lasi la dosieron config.php nurlega, valorigu la opcion \"config_is_read_only“ al vero („true“) en ĝi. Vidu %s",
    "PHP module %s not installed." : "PHP-modulo %s ne instalita.",
    "Please ask your server administrator to install the module." : "Bonvolu peti vian sistemadministranton instali la modulon.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-agordo „%s“ ne egalas al „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Modifo de tiu agordo en „php.ini“ funkciigas Nextcloud-on denove.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ŝajne estas agordita por senigi la entekstajn dokumentarojn. Tio malfunkciigos plurajn kernajn aplikaĵojn.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tion kaŭzas probable kaŝilo aŭ plirapidigilo kiel „Zend OPcache“ aŭ „eAccelerator“.",
    "PHP modules have been installed, but they are still listed as missing?" : "Ĉu PHP-moduloj estas instalitaj, sed ĉiam montritaj kiel mankantaj?",
    "Please ask your server administrator to restart the web server." : "Bonvolu peti vian serviladministranton, ke ŝi aŭ li restartigu la TTT-servilon.",
    "Action \"%s\" not supported or implemented." : "Ago „%s“ ne estas subtenata aŭ realigita.",
    "Authentication failed, wrong token or provider ID given" : "Aŭtentigo malsukcesis: neĝusta ĵetono aŭ provizanto-identigilo specifita",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametroj mankas por realigi la peton. Mankantaj parametroj: „%s“",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Identigilo „%1$s“ jam uziĝas de federnuba provizanto „%2$s“",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Federnuba provizanto kun identigilo „%s“ ne ekzistas.",
    "Could not obtain lock type %d on \"%s\"." : "Ne eblis havi ŝlostipon %d sur „%s“.",
    "Storage unauthorized. %s" : "Konservejo ne permesata. %s",
    "Storage incomplete configuration. %s" : "Nekompleta agordo de konservejo. %s",
    "Storage connection error. %s" : "Konekta eraro al konservejo. %s",
    "Storage is temporarily not available" : "Konservejo provizore ne disponeblas",
    "Storage connection timeout. %s" : "Konekto al konservejo eltempiĝis. %s",
    "Images" : "Bildoj",
    "Text" : "Teksto",
    "Summary" : "Resumo",
    "Translate" : "Traduku",
    "File is currently busy, please try again later" : "La dosiero estas nun okupita, bv. reprovi poste"
},
"nplurals=2; plural=(n != 1);");
